package com.ruoyi.web.plotmanage.mapper;

import com.ruoyi.web.plotmanage.domain.AdManagement;

import java.util.List;

/**
 * 广告位管理Mapper接口
 * 
 * @author cyx
 * @date 2022-11-24
 */
public interface AdManagementMapper 
{
    /**
     * 查询广告位管理
     * 
     * @param id 广告位管理主键
     * @return 广告位管理
     */
    public AdManagement selectAdManagementById(Long id);

    /**
     * 查询广告位管理列表
     * 
     * @param adManagement 广告位管理
     * @return 广告位管理集合
     */
    public List<AdManagement> selectAdManagementList(AdManagement adManagement);

    /**
     * 新增广告位管理
     * 
     * @param adManagement 广告位管理
     * @return 结果
     */
    public int insertAdManagement(AdManagement adManagement);

    /**
     * 修改广告位管理
     * 
     * @param adManagement 广告位管理
     * @return 结果
     */
    public int updateAdManagement(AdManagement adManagement);

    /**
     * 删除广告位管理
     * 
     * @param id 广告位管理主键
     * @return 结果
     */
    public int deleteAdManagementById(Long id);

    /**
     * 批量删除广告位管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAdManagementByIds(Long[] ids);
}
