package com.ruoyi.web.controller.plotmanage;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.web.plotmanage.domain.AdManagement;
import com.ruoyi.web.plotmanage.service.IAdManagementService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 广告位管理Controller
 * 
 * @author cyx
 * @date 2022-11-24
 */
@Api("广告位管理")
@RestController
@RequestMapping("/plotmanage/management")
public class AdManagementController extends BaseController
{
    @Autowired
    private IAdManagementService adManagementService;

    /**
     * 查询广告位管理列表
     */
    @ApiOperation("查询广告位管理列表")
    @PreAuthorize("@ss.hasPermi('plotmanage:management:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdManagement adManagement)
    {
        startPage();
        List<AdManagement> list = adManagementService.selectAdManagementList(adManagement);
        return getDataTable(list);
    }

    /**
     * 导出广告位管理列表
     */
    @ApiOperation("导出广告位管理列表")
    @PreAuthorize("@ss.hasPermi('plotmanage:management:export')")
    @Log(title = "广告位管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdManagement adManagement)
    {
        List<AdManagement> list = adManagementService.selectAdManagementList(adManagement);
        ExcelUtil<AdManagement> util = new ExcelUtil<AdManagement>(AdManagement.class);
        util.exportExcel(response, list, "广告位管理数据");
    }

    /**
     * 获取广告位管理详细信息
     */
    @ApiOperation("获取广告位管理详细信息")
    @PreAuthorize("@ss.hasPermi('plotmanage:management:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(adManagementService.selectAdManagementById(id));
    }

    /**
     * 新增广告位管理
     */
    @ApiOperation("新增广告位管理")
    @PreAuthorize("@ss.hasPermi('plotmanage:management:add')")
    @Log(title = "广告位管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdManagement adManagement)
    {
        return toAjax(adManagementService.insertAdManagement(adManagement));
    }

    /**
     * 修改广告位管理
     */
    @ApiOperation("修改广告位管理")
    @PreAuthorize("@ss.hasPermi('plotmanage:management:edit')")
    @Log(title = "广告位管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdManagement adManagement)
    {
        return toAjax(adManagementService.updateAdManagement(adManagement));
    }

    /**
     * 删除广告位管理
     */
    @ApiOperation("删除广告位管理")
    @PreAuthorize("@ss.hasPermi('plotmanage:management:remove')")
    @Log(title = "广告位管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(adManagementService.deleteAdManagementByIds(ids));
    }
}
